==> plotly-3.5.0rc1-py2.py3-none-any.whl: plotly/validators/violin/__init__.py <==
from ._ysrc import YsrcValidator
from ._yaxis import YAxisValidator
from ._y0 import Y0Validator
from ._y import YValidator
from ._xsrc import XsrcValidator
from ._xaxis import XAxisValidator
from ._x0 import X0Validator
from ._x import XValidator
from ._visible import VisibleValidator
from ._unselected import UnselectedValidator
from ._uirevision import UirevisionValidator
from ._uid import UidValidator
from ._textsrc import TextsrcValidator
from ._text import TextValidator
from ._stream import StreamValidator
from ._spanmode import SpanmodeValidator
from ._span import SpanValidator
from ._side import SideValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._selected import SelectedValidator
from ._scalemode import ScalemodeValidator
from ._scalegroup import ScalegroupValidator
from ._points import PointsValidator
from ._pointpos import PointposValidator
from ._orientation import OrientationValidator
from ._opacity import OpacityValidator
from ._name import NameValidator
from ._meanline import MeanlineValidator
from ._marker import MarkerValidator
from ._line import LineValidator
from ._legendgroup import LegendgroupValidator
from ._jitter import JitterValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hoveron import HoveronValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._fillcolor import FillcolorValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator
from ._box import BoxValidator
from ._bandwidth import BandwidthValidator

==> plotly-3.7.0-py2.py3-none-any.whl: plotly/validators/violin/__init__.py <==
from ._ysrc import YsrcValidator
from ._yaxis import YAxisValidator
from ._y0 import Y0Validator
from ._y import YValidator
from ._xsrc import XsrcValidator
from ._xaxis import XAxisValidator
from ._x0 import X0Validator
from ._x import XValidator
from ._width import WidthValidator
from ._visible import VisibleValidator
from ._unselected import UnselectedValidator
from ._uirevision import UirevisionValidator
from ._uid import UidValidator
from ._textsrc import TextsrcValidator
from ._text import TextValidator
from ._stream import StreamValidator
from ._spanmode import SpanmodeValidator
from ._span import SpanValidator
from ._side import SideValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._selected import SelectedValidator
from ._scalemode import ScalemodeValidator
from ._scalegroup import ScalegroupValidator
from ._points import PointsValidator
from ._pointpos import PointposValidator
from ._orientation import OrientationValidator
from ._opacity import OpacityValidator
from ._offsetgroup import OffsetgroupValidator
from ._name import NameValidator
from ._meanline import MeanlineValidator
from ._marker import MarkerValidator
from ._line import LineValidator
from ._legendgroup import LegendgroupValidator
from ._jitter import JitterValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hovertextsrc import HovertextsrcValidator
from ._hovertext import HovertextValidator
from ._hoveron import HoveronValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._fillcolor import FillcolorValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator
from ._box import BoxValidator
from ._bandwidth import BandwidthValidator
from ._alignmentgroup import AlignmentgroupValidator
